@@ -1,7 +1,5 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-import socket
-
 import autonetkit.ank_json
 import autonetkit.config as config
 import autonetkit.log as log
@@ -11,8 +9,7 @@ use_http_post = config.settings['Http Post']['active']
 if use_http_post:
     import urllib
 
-
-@call_log
+#@call_log
 def format_http_url(host=None, port=None, route='publish'):
     if not host and not port:
         host = config.settings['Http Post']['server']
@@ -22,8 +19,8 @@ def format_http_url(host=None, port=None, route='publish'):
 
 default_http_url = format_http_url()
 
-@call_log
-def update_http(
+#@call_log
+def update_vis(
     anm=None,
     nidb=None,
     http_url=None,
@@ -59,7 +56,7 @@ def update_http(
 
         log.info('Visualisation server running')
 
-@call_log
+#@call_log
 def get_uuid(anm):
     try:
         return config.settings['Http Post']['uuid']
@@ -68,7 +65,7 @@ def get_uuid(anm):
         return 'singleuser'
 
 
-@call_log
+#@call_log
 def highlight(
     nodes=None,
     edges=None,
