@@ -1,15 +1,18 @@
-import autonetkit.log as log
 import autonetkit.ank as ank_utils
+import autonetkit.log as log
 
 """TODO: map the log info/warning/debug to functions here
 # which then map to the appropriate log function, so that can handle either be verbose or not verbose to console with test information.
 """
 
 def validate(anm):
+    log.info("Validating overlay topologies")
     tests_passed = True
     tests_passed = validate_ipv4(anm) and tests_passed
 
     validate_ibgp(anm)
+    validate_igp(anm)
+    check_for_selfloops(anm)
     all_nodes_have_asn(anm)
 
     if tests_passed:
@@ -17,6 +20,13 @@ def validate(anm):
     else:
         log.warning("Some validation tests failed.")
 
+def check_for_selfloops(anm):
+    # checks each overlay for selfloops
+    for overlay in anm:
+        selfloop_count =  overlay._graph.number_of_selfloops()
+        if selfloop_count > 0:
+            log.warning("%s has %s self-loops" % (overlay, selfloop_count))
+
 def all_nodes_have_asn(anm):
     g_phy = anm['phy']
     for node in g_phy.l3devices():
@@ -42,6 +52,24 @@ def validate_ibgp(anm):
         else:
             g_ibgp_v4.log.debug("iBGP v4 topology for ASN%s is connected" % asn)
 
+def validate_igp(anm):
+    import networkx as nx
+    #TODO: test if overlay is present, if not then warn
+    if not anm.has_overlay("igp"):
+        return # no ibgp v4  - eg if ip addressing disabled
+
+    g_igp = anm['igp']
+
+    for asn, devices in ank_utils.groupby("asn", g_igp):
+        asn_subgraph = g_igp.subgraph(devices)
+        graph = asn_subgraph._graph
+        # get subgraph
+        if not nx.is_connected(graph):
+            g_igp.log.warning("IGP topology for ASN%s is disconnected" % asn)
+            #TODO: list connected components - but not the primary?
+        else:
+            g_igp.log.debug("IGP topology for ASN%s is connected" % asn)
+
 
 def all_same(items):
     # based on http://stackoverflow.com/q/3787908
@@ -77,7 +105,7 @@ def validate_ipv4(anm):
 
     # check globally unique ip addresses
     all_ints = [i for n in g_ipv4.l3devices()
-            for i in n.physical_interfaces
+            for i in n.physical_interfaces()
             if i.is_bound] # don't include unbound interfaces
     all_int_ips = [i.ip_address for i in all_ints]
 
