@@ -7,7 +7,7 @@ import netaddr
 from autonetkit.ank import sn_preflen_to_network
 from autonetkit.compiler import sort_sessions
 from autonetkit.compilers.device.router_base import RouterCompiler
-from autonetkit.nidb import config_stanza
+from autonetkit.nidb import ConfigStanza
 
 
 class IosBaseCompiler(RouterCompiler):
@@ -81,9 +81,29 @@ class IosBaseCompiler(RouterCompiler):
 
         super(IosBaseCompiler, self).interfaces(node)
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             interface.use_cdp = node.use_cdp  # use node value
 
+        for interface in node.interfaces:
+            interface.sub_ints = [] # temporary until full subinterfaces
+
+        for interface in node.physical_interfaces():
+            g_ext_conn = self.anm['ext_conn']
+            if node not in g_ext_conn:
+                continue
+
+            node_ext_conn = g_ext_conn.node(node)
+            ext_int = node_ext_conn.interface(interface)
+            for sub_int in ext_int.sub_int or []:
+                stanza = ConfigStanza(
+                    id =sub_int['id'],
+                    ipv4_address =sub_int['ipv4_address'],
+                    ipv4_prefixlen =sub_int['ipv4_prefixlen'],
+                    ipv4_subnet =sub_int['ipv4_subnet'],
+                    dot1q =sub_int['dot1q'],
+                    )
+                interface.sub_ints.append(stanza)
+
     def mpls_oam(self, node):
         g_mpls_oam = self.anm['mpls_oam']
         node.add_stanza("mpls")
@@ -114,20 +134,30 @@ class IosBaseCompiler(RouterCompiler):
     def nailed_up_routes(self, node):
         log.debug('Configuring nailed up routes')
         phy_node = self.anm['phy'].node(node)
-        node.bgp.ipv4_nailed_up_routes = []
-        node.bgp.ipv6_nailed_up_routes = []
 
         if node.is_ebgp_v4 and node.ip.use_ipv4:
             infra_blocks = self.anm['ipv4'].data['infra_blocks'
                     ].get(phy_node.asn) or []
             for infra_route in infra_blocks:
-                node.bgp.ipv4_nailed_up_routes.append(infra_route)
+                stanza = ConfigStanza(
+                    prefix = str(infra_route.network),
+                    netmask = str(infra_route.netmask),
+                    nexthop  = "Null0",
+                    metric = 254,
+                    )
+                node.ipv4_static_routes.append(stanza)
 
         if node.is_ebgp_v6 and node.ip.use_ipv6:
             infra_blocks = self.anm['ipv6'].data['infra_blocks'
                     ].get(phy_node.asn) or []
+            #TODO: setup schema with defaults
             for infra_route in infra_blocks:
-                node.bgp.ipv6_nailed_up_routes.append(infra_route)
+                stanza = ConfigStanza(
+                    prefix =str(infra_route),
+                    nexthop  = "Null0",
+                    metric = 254,
+                    )
+                node.ipv6_static_routes.append(stanza)
 
     def bgp(self, node):
         node.add_stanza("bgp")
@@ -194,14 +224,14 @@ class IosBaseCompiler(RouterCompiler):
             for session in sort_sessions(g_ibgp_v4.edges(vrf_node)):
                 if session.exclude and session.vrf:
                     data = self.ibgp_session_data(session, ip_version=4)
-                    stanza = config_stanza(data)
+                    stanza = ConfigStanza(data)
                     vrf_ibgp_neighbors[session.vrf].append(stanza)
 
             g_ibgp_v6 = self.anm['ibgp_v6']
             for session in sort_sessions(g_ibgp_v6.edges(vrf_node)):
                 if session.exclude and session.vrf:
                     data = self.ibgp_session_data(session, ip_version=6)
-                    stanza = config_stanza(data)
+                    stanza = ConfigStanza(data)
                     vrf_ibgp_neighbors[session.vrf].append(stanza)
 
             # eBGP sessions for this VRF
@@ -211,19 +241,19 @@ class IosBaseCompiler(RouterCompiler):
             for session in sort_sessions(g_ebgp_v4.edges(vrf_node)):
                 if session.exclude and session.vrf:
                     data = self.ebgp_session_data(session, ip_version=4)
-                    stanza = config_stanza(data)
+                    stanza = ConfigStanza(data)
                     vrf_ebgp_neighbors[session.vrf].append(stanza)
 
             for session in sort_sessions(g_ebgp_v6.edges(vrf_node)):
                 if session.exclude and session.vrf:
                     data = self.ebgp_session_data(session, ip_version=6)
-                    stanza = config_stanza(data)
+                    stanza = ConfigStanza(data)
                     vrf_ebgp_neighbors[session.vrf].append(stanza)
 
             for vrf in vrf_node.node_vrf_names:
                 rd_index = vrf_node.rd_indices[vrf]
                 rd = '%s:%s' % (node.asn, rd_index)
-                stanza = config_stanza(
+                stanza = ConfigStanza(
                     vrf=vrf,
                     rd=rd,
                     use_ipv4=node.ip.use_ipv4,
@@ -240,7 +270,7 @@ class IosBaseCompiler(RouterCompiler):
             retain = False
             if vpnv4_node.retain_route_target:
                 retain = True
-            node.bgp.vpnv4 = config_stanza(retain_route_target = retain)
+            node.bgp.vpnv4 = ConfigStanza(retain_route_target = retain)
 
     def vrf_igp_interfaces(self, node):
 
@@ -248,7 +278,7 @@ class IosBaseCompiler(RouterCompiler):
 
         vrf_node = self.anm['vrf'].node(node)
         if vrf_node and vrf_node.vrf_role is 'PE':
-            for interface in node.physical_interfaces:
+            for interface in node.physical_interfaces():
                 vrf_int = self.anm['vrf'].interface(interface)
                 if vrf_int.vrf_name:
                     interface.exclude_igp = True
@@ -268,7 +298,7 @@ class IosBaseCompiler(RouterCompiler):
                 rd_index = vrf_node.rd_indices[vrf]
                 rd = '%s:%s' % (node.asn, rd_index)
 
-                stanza = config_stanza(vrf = vrf, rd = rd, route_target = route_target)
+                stanza = ConfigStanza(vrf = vrf, rd = rd, route_target = route_target)
                 node.vrf.vrfs.append(stanza)
 
             for interface in node.interfaces:
@@ -284,7 +314,7 @@ class IosBaseCompiler(RouterCompiler):
             # Add PE -> P, PE -> PE interfaces to MPLS LDP
 
             node.mpls.ldp_interfaces = []
-            for interface in node.physical_interfaces:
+            for interface in node.physical_interfaces():
                 mpls_ldp_int = self.anm['mpls_ldp'].interface(interface)
                 if mpls_ldp_int.is_bound:
                     node.mpls.ldp_interfaces.append(interface.id)
@@ -292,7 +322,7 @@ class IosBaseCompiler(RouterCompiler):
 
         if vrf_node and vrf_node.vrf_role is 'P':
             node.mpls.ldp_interfaces = []
-            for interface in node.physical_interfaces:
+            for interface in node.physical_interfaces():
                 node.mpls.ldp_interfaces.append(interface.id)
 
         vrf_node = self.anm['vrf'].node(node)
@@ -308,7 +338,7 @@ class IosBaseCompiler(RouterCompiler):
 
     def ospf(self, node):
         super(IosBaseCompiler, self).ospf(node)
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             phy_int = self.anm['phy'].interface(interface)
 
             ospf_int = phy_int['ospf']
@@ -316,7 +346,7 @@ class IosBaseCompiler(RouterCompiler):
                 if interface.exclude_igp:
                     continue  # don't configure IGP for this interface
 
-                #TODO: use config_stanza here
+                #TODO: use ConfigStanza here
                 interface.ospf = {
                     'cost': ospf_int.cost,
                     'area': ospf_int.area,
@@ -330,7 +360,7 @@ class IosBaseCompiler(RouterCompiler):
 
     def eigrp(self, node):
         super(IosBaseCompiler, self).eigrp(node)
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             phy_int = self.anm['phy'].interface(interface)
 
             eigrp_int = phy_int['eigrp']
@@ -351,7 +381,7 @@ class IosBaseCompiler(RouterCompiler):
 
     def isis(self, node):
         super(IosBaseCompiler, self).isis(node)
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             isis_int = self.anm['isis'].interface(interface)
             edges = isis_int.edges()
             if not isis_int.is_bound:
@@ -413,6 +443,7 @@ class IosClassicCompiler(IosBaseCompiler):
 
         self.mpls_te(node)
         self.mpls_oam(node)
+        self.gre(node)
 
         phy_node = self.anm['phy'].node(node)
         if phy_node.device_subtype == 'IOSv':
@@ -429,6 +460,7 @@ class IosClassicCompiler(IosBaseCompiler):
 
             # only copy across for certain reference platforms
 
+            node.use_onepk = phy_node.use_onepk
             node.transport_input_ssh_telnet = True
             node.include_csr = True
 
@@ -453,6 +485,40 @@ class IosClassicCompiler(IosBaseCompiler):
             }
 
                           # TODO: add wrapper for this
+    def gre(self, node):
+        node.gre_tunnels = []
+        if not self.anm.has_overlay('gre_tunnel'):
+            return
+
+        g_gre_tunnel = self.anm['gre_tunnel']
+        if node not in g_gre_tunnel:
+            return   # no gre tunnel for node
+
+        gre_node = g_gre_tunnel.node(node)
+        neighbors = gre_node.neighbors()
+        for index, neigh in enumerate(neighbors, start=1):
+            stanza = ConfigStanza(id = index, endpoint = neigh)
+
+            #TODO: try/except here
+            #TODO: Explain logic here
+            src_int = g_gre_tunnel.edge(node, neigh).src_int
+            tunnel_source  = node.interface(src_int).id
+            stanza.source = tunnel_source
+            stanza.destination = "0.0.0.0" # placeholder for user to replace
+
+            if neigh.tunnel_enabled_ipv4:
+                ip_address = neigh.tunnel_ipv4_address
+                cidr = neigh.tunnel_ipv4_cidr
+                stanza.ipv4_address = ip_address
+                stanza.ipv4_subnet = cidr
+                stanza.use_ipv4 = True
+
+            if neigh.tunnel_enabled_ipv6:
+                cidr = neigh.tunnel_ipv6_cidr
+                stanza.ipv4_subnet = cidr
+                stanza.use_ipv6 = True
+
+            node.gre_tunnels.append(stanza)
 
     def mpls_te(self, node):
         super(IosClassicCompiler, self).mpls_te(node)
@@ -463,7 +529,7 @@ class IosClassicCompiler(IosBaseCompiler):
 
         mpls_te_node = g_mpls_te.node(node)
 
-        for interface in mpls_te_node.physical_interfaces:
+        for interface in mpls_te_node.physical_interfaces():
             nidb_interface = self.nidb.interface(interface)
             if not interface.is_bound:
                 log.debug('Not enable MPLS and RSVP for interface %s on %s '
@@ -488,7 +554,7 @@ class IosClassicCompiler(IosBaseCompiler):
         # TODO: sort the peer list by peer IP
 
         for peer in node.bgp.ibgp_neighbors:
-            peer = config_stanza(peer)
+            peer = ConfigStanza(peer)
             peer.remote_ip = peer.loopback
             if peer.use_ipv4:
                 if node.is_ebgp_v4:
@@ -500,7 +566,7 @@ class IosClassicCompiler(IosBaseCompiler):
                 ipv6_peers.append(peer)
 
         for peer in node.bgp.ibgp_rr_parents:
-            peer = config_stanza(peer)
+            peer = ConfigStanza(peer)
             peer.remote_ip = peer.loopback
             if peer.use_ipv4:
                 if node.is_ebgp_v4:
@@ -512,7 +578,7 @@ class IosClassicCompiler(IosBaseCompiler):
                 ipv6_peers.append(peer)
 
         for peer in node.bgp.ibgp_rr_clients:
-            peer = config_stanza(peer)
+            peer = ConfigStanza(peer)
             peer.rr_client = True
             peer.remote_ip = peer.loopback
             if peer.use_ipv4:
@@ -525,7 +591,7 @@ class IosClassicCompiler(IosBaseCompiler):
                 ipv6_peers.append(peer)
 
         for peer in node.bgp.ebgp_neighbors:
-            peer = config_stanza(peer)
+            peer = ConfigStanza(peer)
             peer.is_ebgp = True
             peer.remote_ip = peer.dst_int_ip
             if peer.use_ipv4:
@@ -544,20 +610,20 @@ class IosClassicCompiler(IosBaseCompiler):
                 if not neigh.use_ipv4:
                     continue
 
-                neigh_data = config_stanza(neigh)
+                neigh_data = ConfigStanza(neigh)
                 vpnv4_neighbors.append(neigh_data)
 
             for neigh in node.bgp.ibgp_rr_clients:
                 if not neigh.use_ipv4:
                     continue
-                neigh_data = config_stanza(neigh)
+                neigh_data = ConfigStanza(neigh)
                 neigh_data.rr_client = True
                 vpnv4_neighbors.append(neigh_data)
 
             for neigh in node.bgp.ibgp_rr_parents:
                 if not neigh.use_ipv4:
                     continue
-                neigh_data = config_stanza(neigh)
+                neigh_data = ConfigStanza(neigh)
                 vpnv4_neighbors.append(neigh_data)
 
         vpnv4_neighbors = sorted(vpnv4_neighbors, key=lambda x: \
@@ -583,9 +649,9 @@ class IosXrCompiler(IosBaseCompiler):
         mpls_te_interfaces = []
         mpls_te_node = g_mpls_te.node(node)
 
-        for interface in mpls_te_node.physical_interfaces:
+        for interface in mpls_te_node.physical_interfaces():
             nidb_interface = self.nidb.interface(interface)
-            stanza = config_stanza(id = nidb_interface.id,
+            stanza = ConfigStanza(id = nidb_interface.id,
                                    bandwidth_percent = 100)
             rsvp_interfaces.append(stanza)
 
@@ -605,7 +671,7 @@ class IosXrCompiler(IosBaseCompiler):
         ipv4_interfaces = []
         ipv6_interfaces = []
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
 
@@ -613,7 +679,7 @@ class IosXrCompiler(IosBaseCompiler):
             if eigrp_int and eigrp_int.is_bound:
                 #TODO: for here and below use stanza directly
                 data = {'id': interface.id, 'passive': False}
-                stanza = config_stanza(**data)
+                stanza = ConfigStanza(**data)
                 if node.eigrp.use_ipv4:
                     ipv4_interfaces.append(stanza)
                 if node.eigrp.use_ipv6:
@@ -621,7 +687,7 @@ class IosXrCompiler(IosBaseCompiler):
 
         loopback_zero = node.loopback_zero
         data = {'id': node.loopback_zero.id, 'passive': True}
-        stanza = config_stanza(**data)
+        stanza = ConfigStanza(**data)
         if node.eigrp.use_ipv4:
             ipv4_interfaces.append(stanza)
         if node.eigrp.use_ipv6:
@@ -634,7 +700,7 @@ class IosXrCompiler(IosBaseCompiler):
         super(IosXrCompiler, self).isis(node)
         node.isis.isis_links = []
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
 
@@ -652,7 +718,7 @@ class IosXrCompiler(IosBaseCompiler):
                     data['mtu'] = interface.isis.hello_padding_disable
 
                 #TODO: make stanza
-                stanza = config_stanza(**data)
+                stanza = ConfigStanza(**data)
                 node.isis.isis_links.append(stanza)
 
 
