@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 from autonetkit.compiler import sort_sessions
 from autonetkit.compilers.device.device_base import DeviceCompiler
-from autonetkit.nidb import config_stanza
+from autonetkit.nidb import ConfigStanza
 
 import autonetkit.plugins.naming as naming
 import autonetkit.log as log
@@ -35,7 +35,7 @@ class RouterCompiler(DeviceCompiler):
             use_ipv4 = False
             use_ipv6 = True
 
-        #TODO: return config_stanza rather than a dict
+        #TODO: return ConfigStanza rather than a dict
         data = {  # TODO: this is platform dependent???
             'neighbor': neigh.label,
             'use_ipv4': use_ipv4,
@@ -62,7 +62,10 @@ class RouterCompiler(DeviceCompiler):
             use_ipv4 = False
             use_ipv6 = True
 
-        #TODO: return config_stanza rather than a dict
+        md5_password = session.md5_password
+        multihop = session.multihop
+
+        #TODO: return ConfigStanza rather than a dict
         data = {  # TODO: change templates to access from node.bgp.lo_int
             'neighbor': neigh.label,
             'use_ipv4': use_ipv4,
@@ -72,6 +75,8 @@ class RouterCompiler(DeviceCompiler):
             'local_int_ip': local_int_ip,
             'dst_int_ip': dst_int_ip,
             'update_source': node.loopback_zero.id,
+            'md5_password': md5_password,
+            'multihop': multihop,
             }
         return data
 
@@ -86,12 +91,17 @@ class RouterCompiler(DeviceCompiler):
         phy_node = self.anm['phy'].node(node)
         ipv4_node = self.anm['ipv4'].node(node)
 
+        node.global_custom_config = phy_node.custom_config
+
         node.add_stanza("ip")
         node.ip.use_ipv4 = phy_node.use_ipv4 or False
         node.ip.use_ipv6 = phy_node.use_ipv6 or False
         if not (node.ip.use_ipv4 and node.ip.use_ipv6):
             node.log.debug('Neither IPv4 nor IPv6 specified: using default IPv4')
 
+
+        self.static_routes(node)
+
             # node.ip.use_ipv4 = True
 
         node.label = naming.network_hostname(phy_node)
@@ -125,11 +135,37 @@ class RouterCompiler(DeviceCompiler):
         if use_bgp:
             self.bgp(node)
 
+    def static_routes(self, node):
+        node.ipv4_static_routes = []
+        ipv4_node = self.anm['ipv4'].node(node)
+        if ipv4_node and ipv4_node.static_routes:
+            for route in ipv4_node.static_routes:
+                stanza = ConfigStanza(
+                    prefix = route.prefix,
+                    netmask = route.netmask,
+                    nexthop = route.nexthop,
+                    metric = route.metric,
+                    )
+                node.ipv4_static_routes.append(stanza)
+
+        node.ipv6_static_routes = []
+        ipv6_node = self.anm['ipv6'].node(node)
+        if ipv6_node and ipv6_node.static_routes:
+            for route in ipv6_node.static_routes:
+                stanza = ConfigStanza(
+                    prefix = route.prefix,
+                    nexthop = route.nexthop,
+                    metric = route.metric,
+                    )
+                node.ipv6_static_routes.append(stanza)
+
     def interfaces(self, node):
         node.interfaces = []
 
         node.loopback_zero.id = self.lo_interface
         node.loopback_zero.description = 'Loopback'
+        phy_node = self.anm['phy'].node(node)
+        node.loopback_zero.custom_config = phy_node.loopback_zero.custom_config
 
         if node.ip.use_ipv4:
             ipv4_node = self.anm['ipv4'].node(node)
@@ -142,18 +178,18 @@ class RouterCompiler(DeviceCompiler):
             #node.loopback_zero.ipv6_address = ipv6_node.loopback
             #node.loopback_zero.ipv6_subnet = node.loopback_subnet
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             phy_int = self.anm['phy'].interface(interface)
             interface.physical = True
 
             # TODO: allocate ID in platform compiler
 
             if not phy_int:
-
                 # for instance if added as management interface to nidb in compile
-
                 continue
 
+            interface.custom_config = phy_int.custom_config
+
             interface.description = phy_int.description
             remote_edges = phy_int.edges()
             if len(remote_edges):
@@ -193,7 +229,7 @@ class RouterCompiler(DeviceCompiler):
                     except AttributeError:
                         log.warning("Unable to format interface ")
 
-        for interface in node.loopback_interfaces:
+        for interface in node.loopback_interfaces():
 
             # TODO: check if nonzero is different to __eq__
 
@@ -236,6 +272,8 @@ class RouterCompiler(DeviceCompiler):
         ospf_node = g_ospf.node(node)
         ospf_stanza = node.add_stanza("ospf")
 
+        ospf_stanza.custom_config = ospf_node.custom_config
+
         node.ospf.ipv4_mpls_te = False  # default, inherited enable if necessary
 
         node.ospf.loopback_area = g_ospf.node(node).area or 0
@@ -249,7 +287,7 @@ class RouterCompiler(DeviceCompiler):
         from collections import defaultdict
         interfaces_by_area = defaultdict(list)
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
 
@@ -259,7 +297,7 @@ class RouterCompiler(DeviceCompiler):
                 #TODO: can we remove the next line?
                 area = str(area)  # can't serialize IPAddress object to JSON
                 #TODO: put in interface rather than interface.id for consistency
-                stanza = config_stanza(id = interface.id,
+                stanza = ConfigStanza(id = interface.id,
                         cost = int(ospf_int.cost), passive = False)
 
                 if node.ip.use_ipv4:
@@ -275,14 +313,14 @@ class RouterCompiler(DeviceCompiler):
         ospf_loopback_zero = g_ospf.interface(loopback_zero)
         router_area = ospf_loopback_zero.area  # area assigned to router
         router_area = str(router_area)  # can't serialize IPAddress object to JSON
-        stanza = config_stanza(id = node.loopback_zero.id,
+        stanza = ConfigStanza(id = node.loopback_zero.id,
             cost = 0, passive = True)
         interfaces_by_area[router_area].append(stanza)
 
-        node.ospf.interfaces_by_area = config_stanza(**interfaces_by_area)
+        node.ospf.interfaces_by_area = ConfigStanza(**interfaces_by_area)
 
         added_networks = set()
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
             ipv4_int = g_ipv4.interface(interface)
@@ -304,7 +342,7 @@ class RouterCompiler(DeviceCompiler):
             if ospf_int and ospf_int.is_bound and network \
                 not in added_networks:  # don't add more than once
                 added_networks.add(network)
-                link_stanza = config_stanza(network = network, interface = interface, area = ospf_int.area)
+                link_stanza = ConfigStanza(network = network, interface = interface, area = ospf_int.area)
                 node.ospf.ospf_links.append(link_stanza)
 
             # also add networks for subnets to servers in the same AS
@@ -317,7 +355,8 @@ class RouterCompiler(DeviceCompiler):
             g_ipv6 = self.anm['ipv6']
         asn = phy_node.asn
         node.asn = asn
-        node.add_stanza("bgp")
+        bgp_stanza = node.add_stanza("bgp")
+        bgp_stanza.custom_config = phy_node['bgp'].custom_config
 
         node.bgp.ipv4_advertise_subnets = []
         if node.ip.use_ipv4:
@@ -340,7 +379,7 @@ class RouterCompiler(DeviceCompiler):
                 continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
 
             data = self.ibgp_session_data(session, ip_version=4)
-            bgp_stanza = config_stanza(**data)
+            bgp_stanza = ConfigStanza(**data)
 
             direction = session.direction
             if direction == 'down':
@@ -359,7 +398,7 @@ class RouterCompiler(DeviceCompiler):
                     log.debug('Skipping excluded ibgp session %s' % session)
                     continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
                 data = self.ibgp_session_data(session, ip_version=6)
-                bgp_stanza = config_stanza(**data)
+                bgp_stanza = ConfigStanza(**data)
 
                 direction = session.direction
                 if direction == 'down':
@@ -384,18 +423,17 @@ class RouterCompiler(DeviceCompiler):
                 log.debug('Skipping excluded ebgp session %s' % session)
                 continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
             data = self.ebgp_session_data(session, ip_version=4)
-            bgp_stanza = config_stanza(**data)
+            bgp_stanza = ConfigStanza(**data)
             ebgp_neighbors.append(bgp_stanza)
 
         if node.ip.use_ipv6:
             g_ebgp_v6 = self.anm['ebgp_v6']
             for session in sort_sessions(g_ebgp_v6.edges(phy_node)):
                 if session.exclude:
-                    print "Exclude"
                     log.debug('Skipping excluded ebgp session %s' % session)
                     continue  # exclude from regular ibgp config (eg VRF, VPLS, etc)
                 data = self.ebgp_session_data(session, ip_version=6)
-                bgp_stanza = config_stanza(**data)
+                bgp_stanza = ConfigStanza(**data)
                 ebgp_neighbors.append(bgp_stanza)
 
         ebgp_neighbors = sorted(ebgp_neighbors, key = lambda x: x.asn)
@@ -404,13 +442,15 @@ class RouterCompiler(DeviceCompiler):
         return
 
     def eigrp(self, node):
+
         g_eigrp = self.anm['eigrp']
         g_ipv4 = self.anm['ipv4']
         eigrp_node = self.anm['eigrp'].node(node)
         node.eigrp.process_id = eigrp_node.process_id
+        node.eigrp.custom_config = eigrp_node.custom_config
 
         ipv4_networks = set()
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
             ipv4_int = g_ipv4.interface(interface)
@@ -431,10 +471,11 @@ class RouterCompiler(DeviceCompiler):
         g_isis = self.anm['isis']
         isis_node = g_isis.node(node)
         process_id = isis_node.process_id
+        node.isis.custom_config = isis_node.custom_config
 
         node.isis.ipv4_mpls_te = False  # default, inherited enable if necessary
 
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if interface.exclude_igp:
                 continue  # don't configure IGP for this interface
 
