@@ -13,7 +13,7 @@ from autonetkit.compilers.device.cisco import (IosBaseCompiler,
                                                IosXrCompiler, NxOsCompiler,
                                                StarOsCompiler)
 from autonetkit.compilers.platform.platform_base import PlatformCompiler
-from autonetkit.nidb import config_stanza
+from autonetkit.nidb import ConfigStanza
 
 
 class CiscoCompiler(PlatformCompiler):
@@ -82,7 +82,7 @@ class CiscoCompiler(PlatformCompiler):
         for x in itertools.count(0):
             yield x
 
-    @call_log
+    #@call_log
     def compile(self):
         self.copy_across_ip_addresses()
         self.compile_devices()
@@ -105,7 +105,7 @@ class CiscoCompiler(PlatformCompiler):
         #TODO: use a namedtuple
         return to_memory, use_mgmt_interfaces, dst_folder
 
-    @call_log
+    #@call_log
     def compile_devices(self):
         g_phy = self.anm['phy']
 
@@ -131,23 +131,23 @@ class CiscoCompiler(PlatformCompiler):
         external_connectors = [n for n in g_phy
             if n.host == self.host and n.device_type == "external_connector"]
         for phy_node in external_connectors:
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.indices = phy_node.indices
+            DmNode = self.nidb.node(phy_node)
+            DmNode.indices = phy_node.indices
 
         for phy_node in g_phy.l3devices(host=self.host):
             loopback_ids = self.loopback_interface_ids()
             # allocate loopbacks to routes (same for all ios variants)
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.indices = phy_node.indices
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.indices = phy_node.indices
 
-            for interface in nidb_node.loopback_interfaces:
-                if interface != nidb_node.loopback_zero:
+            for interface in DmNode.loopback_interfaces():
+                if interface != DmNode.loopback_zero:
                     interface.id = loopback_ids.next()
 
             # numeric ids
             numeric_int_ids = self.numeric_interface_ids()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 phy_numeric_id = phy_node.interface(interface).numeric_id
                 if phy_numeric_id is None:
                     #TODO: remove numeric ID code
@@ -164,24 +164,24 @@ class CiscoCompiler(PlatformCompiler):
 
         ubuntu_compiler = UbuntuCompiler(self.nidb, self.anm)
         for phy_node in g_phy.servers(host=self.host):
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.add_stanza("ip")
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.add_stanza("ip")
 
             #TODO: look at server syntax also, same as for routers
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 phy_specified_id = phy_node.interface(interface).specified_id
                 if phy_specified_id is not None:
                     interface.id = phy_specified_id
 
                 #interface.id = self.numeric_to_interface_label_linux(interface.numeric_id)
                 #print "numeric", interface.numeric_id, interface.id
-                nidb_node.ip.use_ipv4 = phy_node.use_ipv4
-                nidb_node.ip.use_ipv6 = phy_node.use_ipv6
+                DmNode.ip.use_ipv4 = phy_node.use_ipv4
+                DmNode.ip.use_ipv6 = phy_node.use_ipv6
 
                 #TODO: clean up interface handling
             numeric_int_ids = self.numeric_interface_ids()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 phy_int = phy_node.interface(interface)
                 phy_numeric_id = phy_node.interface(interface).numeric_id
                 if phy_numeric_id is None:
@@ -197,21 +197,21 @@ class CiscoCompiler(PlatformCompiler):
                 #TODO: make this part of the base device compiler, which server/router inherits
 
             if use_mgmt_interfaces: # not these are physical interfaces; configure after previous config steps
-                mgmt_int = nidb_node.add_interface(management = True, description = "eth0")
+                mgmt_int = DmNode.add_interface(management = True, description = "eth0")
                 mgmt_int_id = "eth0"
                 mgmt_int.id = mgmt_int_id
 
                     # render route config
-            nidb_node = self.nidb.node(phy_node)
-            ubuntu_compiler.compile(nidb_node)
+            DmNode = self.nidb.node(phy_node)
+            ubuntu_compiler.compile(DmNode)
 
             if not phy_node.dont_configure_static_routing:
-                nidb_node.render.template = os.path.join("templates", "linux", "static_route.mako")
+                DmNode.render.template = os.path.join("templates", "linux", "static_route.mako")
                 if to_memory:
-                    nidb_node.render.to_memory = True
+                    DmNode.render.to_memory = True
                 else:
-                    nidb_node.render.dst_folder = dst_folder
-                    nidb_node.render.dst_file = "%s.conf" % naming.network_hostname(
+                    DmNode.render.dst_folder = dst_folder
+                    DmNode.render.dst_file = "%s.conf" % naming.network_hostname(
                         phy_node)
 
 
@@ -221,14 +221,14 @@ class CiscoCompiler(PlatformCompiler):
         host_routers = g_phy.routers(host=self.host)
         ios_nodes = (n for n in host_routers if n.syntax in ("ios", "ios_xe"))
         for phy_node in ios_nodes:
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.render.template = os.path.join("templates","ios.mako")
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.render.template = os.path.join("templates","ios.mako")
             if to_memory:
-                nidb_node.render.to_memory = True
+                DmNode.render.to_memory = True
             else:
-                nidb_node.render.dst_folder = dst_folder
-                nidb_node.render.dst_file = "%s.conf" % naming.network_hostname(
+                DmNode.render.dst_folder = dst_folder
+                DmNode.render.dst_file = "%s.conf" % naming.network_hostname(
                     phy_node)
 
             #TODO: write function that assigns interface number excluding those already taken
@@ -255,14 +255,14 @@ class CiscoCompiler(PlatformCompiler):
                 if phy_node.device_subtype == "CSR1000v":
                     mgmt_int_id = "GigabitEthernet1"
 
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 #TODO: use this code block once for all routers
                 if not interface.id:
                     interface.id = numeric_to_interface_label(interface.numeric_id)
 
-            ios_compiler.compile(nidb_node)
+            ios_compiler.compile(DmNode)
             if use_mgmt_interfaces:
-                mgmt_int = nidb_node.add_interface(management = True)
+                mgmt_int = DmNode.add_interface(management = True)
                 mgmt_int.id = mgmt_int_id
 
         try:
@@ -272,81 +272,81 @@ class CiscoCompiler(PlatformCompiler):
             ios_xr_compiler = IosXrCompiler(self.nidb, self.anm)
 
         for phy_node in g_phy.routers(host=self.host, syntax='ios_xr'):
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.render.template = os.path.join("templates","ios_xr","router.conf.mako")
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.render.template = os.path.join("templates","ios_xr","router.conf.mako")
             if to_memory:
-                nidb_node.render.to_memory = True
+                DmNode.render.to_memory = True
             else:
-                nidb_node.render.dst_folder = dst_folder
-                nidb_node.render.dst_file = "%s.conf" % naming.network_hostname(
+                DmNode.render.dst_folder = dst_folder
+                DmNode.render.dst_file = "%s.conf" % naming.network_hostname(
                     phy_node)
 
             # Assign interfaces
             int_ids = self.interface_ids_ios_xr()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 if not interface.id:
                     interface.id = self.numeric_to_interface_label_ios_xr(interface.numeric_id)
 
-            ios_xr_compiler.compile(nidb_node)
+            ios_xr_compiler.compile(DmNode)
 
             if use_mgmt_interfaces:
                 mgmt_int_id = "mgmteth0/0/CPU0/0"
-                mgmt_int = nidb_node.add_interface(management = True)
+                mgmt_int = DmNode.add_interface(management = True)
                 mgmt_int.id = mgmt_int_id
 
         nxos_compiler = NxOsCompiler(self.nidb, self.anm)
         for phy_node in g_phy.routers(host=self.host, syntax='nx_os'):
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.render.template = os.path.join("templates","nx_os.mako")
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.render.template = os.path.join("templates","nx_os.mako")
             if to_memory:
-                nidb_node.render.to_memory = True
+                DmNode.render.to_memory = True
             else:
-                nidb_node.render.dst_folder = dst_folder
-                nidb_node.render.dst_file = "%s.conf" % naming.network_hostname(
+                DmNode.render.dst_folder = dst_folder
+                DmNode.render.dst_file = "%s.conf" % naming.network_hostname(
                     phy_node)
 
             # Assign interfaces
             int_ids = self.interface_ids_nxos()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 if not interface.id:
                     interface.id = self.numeric_to_interface_label_nxos(interface.numeric_id)
 
-            nidb_node.supported_features = config_stanza(mpls_te = False, mpls_oam = False, vrf = False)
+            DmNode.supported_features = ConfigStanza(mpls_te = False, mpls_oam = False, vrf = False)
 
-            nxos_compiler.compile(nidb_node)
+            nxos_compiler.compile(DmNode)
             #TODO: make this work other way around
 
             if use_mgmt_interfaces:
                 mgmt_int_id = "mgmt0"
-                mgmt_int = nidb_node.add_interface(management = True)
+                mgmt_int = DmNode.add_interface(management = True)
                 mgmt_int.id = mgmt_int_id
 
         staros_compiler = StarOsCompiler(self.nidb, self.anm)
         for phy_node in g_phy.routers(host=self.host, syntax='StarOS'):
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.render.template = os.path.join("templates","staros.mako")
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.render.template = os.path.join("templates","staros.mako")
             if to_memory:
-                nidb_node.render.to_memory = True
+                DmNode.render.to_memory = True
             else:
-                nidb_node.render.dst_folder = dst_folder
-                nidb_node.render.dst_file = "%s.conf" % naming.network_hostname(
+                DmNode.render.dst_folder = dst_folder
+                DmNode.render.dst_file = "%s.conf" % naming.network_hostname(
                     phy_node)
 
             # Assign interfaces
             int_ids = self.interface_ids_nxos()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 if not interface.id:
                     interface.id = self.numeric_to_interface_label_star_os(interface.numeric_id)
 
-            staros_compiler.compile(nidb_node)
+            staros_compiler.compile(DmNode)
             #TODO: make this work other way around
 
             if use_mgmt_interfaces:
                 mgmt_int_id = "ethernet 1/1"
-                mgmt_int = nidb_node.add_interface(management = True)
+                mgmt_int = DmNode.add_interface(management = True)
                 mgmt_int.id = mgmt_int_id
 
 
@@ -355,23 +355,23 @@ class CiscoCompiler(PlatformCompiler):
         use_mgmt_interfaces = g_phy.data.mgmt_interfaces_enabled
         if not use_mgmt_interfaces:
             return
-        lab_topology = self.nidb.topology[self.host]
+        lab_topology = self.nidb.topology(self.host)
         oob_management_ips = {}
 
         hosts_to_allocate = sorted(self.nidb.l3devices(host=self.host))
         dhcp_subtypes = {"vios"}
         dhcp_hosts = [h for h in hosts_to_allocate if h.device_subtype in dhcp_subtypes]
 
-        for nidb_node in hosts_to_allocate:
-            for interface in nidb_node.physical_interfaces:
+        for DmNode in hosts_to_allocate:
+            for interface in DmNode.physical_interfaces():
                 if interface.management:
                     interface.description = "OOB Management"
                     interface.physical = True
                     interface.mgmt = True
                     interface.comment = "Configured on launch"
-                    if nidb_node.ip.use_ipv4:
+                    if DmNode.ip.use_ipv4:
                         interface.use_ipv4 = False # want a "no ip address" stanza
-                    if nidb_node.use_cdp:
+                    if DmNode.use_cdp:
                         interface.use_cdp = True # ensure CDP activated
-                    if nidb_node in dhcp_hosts:
+                    if DmNode in dhcp_hosts:
                         interface.use_dhcp = True
