@@ -4,7 +4,7 @@ from autonetkit.compilers.platform.platform_base import PlatformCompiler
 import itertools
 import autonetkit.ank as ank
 #from autonetkit.compilers.device.
-from autonetkit.nidb import config_stanza
+from autonetkit.nidb import ConfigStanza
 
 class JunosphereCompiler(PlatformCompiler):
     """Junosphere Platform Compiler"""
@@ -19,18 +19,18 @@ class JunosphereCompiler(PlatformCompiler):
         g_phy = self.anm['phy']
         junos_compiler = JunosCompiler(self.nidb, self.anm)
         for phy_node in g_phy.routers(host=self.host, syntax='junos'):
-            nidb_node = self.nidb.node(phy_node)
-            nidb_node.add_stanza("render")
-            nidb_node.render.template = os.path.join("templates","junos.mako")
-            nidb_node.render.dst_folder = os.path.join("rendered",self.host,"junosphere")
-            nidb_node.render.dst_file = "%s.conf" % ank.name_folder_safe(
+            DmNode = self.nidb.node(phy_node)
+            DmNode.add_stanza("render")
+            DmNode.render.template = os.path.join("templates","junos.mako")
+            DmNode.render.dst_folder = os.path.join("rendered",self.host,"junosphere")
+            DmNode.render.dst_file = "%s.conf" % ank.name_folder_safe(
                 phy_node.label)
 
             int_ids = self.interface_ids()
-            for interface in nidb_node.physical_interfaces:
+            for interface in DmNode.physical_interfaces():
                 interface.unit = 0
                 interface.id = int_ids.next()
 
-            junos_compiler.compile(nidb_node)
+            junos_compiler.compile(DmNode)
 
 
