@@ -1,10 +1,8 @@
 import autonetkit.ank as ank_utils
 import autonetkit.log as log
-
-
 from autonetkit.ank_utils import call_log
 
-@call_log
+#@call_log
 def build_ibgp_v4(anm):
     #TODO: remove the bgp layer and have just ibgp and ebgp
     # TODO: build from design rules, currently just builds from ibgp links in bgp layer
@@ -13,11 +11,13 @@ def build_ibgp_v4(anm):
     g_phy = anm['phy']
     g_ibgpv4 = anm.add_overlay("ibgp_v4", directed=True)
     ipv4_nodes = set(g_phy.routers("use_ipv4"))
+    if len(ipv4_nodes) == 0:
+        return
     g_ibgpv4.add_nodes_from((n for n in g_bgp if n in ipv4_nodes),
             retain = ["ibgp_role", "hrr_cluster", "rr_cluster"] )
     g_ibgpv4.add_edges_from(g_bgp.edges(type="ibgp"), retain="direction")
 
-@call_log
+#@call_log
 def build_ibgp_v6(anm):
     #TODO: remove the bgp layer and have just ibgp and ebgp
     # TODO: build from design rules, currently just builds from ibgp links in bgp layer
@@ -26,11 +26,13 @@ def build_ibgp_v6(anm):
     g_phy = anm['phy']
     g_ibgpv6 = anm.add_overlay("ibgp_v6", directed=True)
     ipv6_nodes = set(g_phy.routers("use_ipv6"))
+    if len(ipv6_nodes) == 0:
+        return
     g_ibgpv6.add_nodes_from((n for n in g_bgp if n in ipv6_nodes),
             retain = ["ibgp_role", "hrr_cluster", "rr_cluster"] )
     g_ibgpv6.add_edges_from(g_bgp.edges(type="ibgp"), retain="direction")
 
-@call_log
+#@call_log
 def build_ebgp_v4(anm):
     #TODO: remove the bgp layer and have just ibgp and ebgp
     # TODO: build from design rules, currently just builds from ibgp links in bgp layer
@@ -38,9 +40,12 @@ def build_ebgp_v4(anm):
     g_phy = anm['phy']
     g_ebgpv4 = anm.add_overlay("ebgp_v4", directed=True)
     ipv4_nodes = set(g_phy.routers("use_ipv4"))
+    if len(ipv4_nodes) == 0:
+        return
     g_ebgpv4.add_nodes_from(n for n in g_ebgp if n in ipv4_nodes)
     g_ebgpv4.add_edges_from(g_ebgp.edges(), retain="direction")
 
+#@call_log
 def build_ebgp_v6(anm):
     #TODO: remove the bgp layer and have just ibgp and ebgp
     # TODO: build from design rules, currently just builds from ibgp links in bgp layer
@@ -48,43 +53,26 @@ def build_ebgp_v6(anm):
     g_phy = anm['phy']
     g_ebgpv6 = anm.add_overlay("ebgp_v6", directed=True)
     ipv6_nodes = set(g_phy.routers("use_ipv6"))
+    if len(ipv6_nodes) == 0:
+        return
     g_ebgpv6.add_nodes_from(n for n in g_ebgp if n in ipv6_nodes)
     g_ebgpv6.add_edges_from(g_ebgp.edges(), retain="direction")
 
-
-@call_log
+#@call_log
 def build_ebgp(anm):
     g_in = anm['input']
     g_phy = anm['phy']
+    g_l3 = anm['layer3']
+
     g_ebgp = anm.add_overlay("ebgp", directed=True)
-    g_ebgp.add_nodes_from(g_in.routers())
-    ebgp_edges = [e for e in g_in.edges() if not e.attr_equal("asn")]
+
+    g_ebgp.add_nodes_from(g_l3.routers())
+    ank_utils.copy_int_attr_from(g_l3, g_ebgp, "multipoint")
+
+    ebgp_edges = [e for e in g_l3.edges() if e.src.asn != e.dst.asn]
     g_ebgp.add_edges_from(ebgp_edges, bidirectional=True, type='ebgp')
 
-    ebgp_switches = [n for n in g_in.switches()
-            if not ank_utils.neigh_equal(g_phy, n, "asn")]
-    g_ebgp.add_nodes_from(ebgp_switches, retain=['asn'])
-    g_ebgp.log.debug("eBGP switches are %s" % ebgp_switches)
-    g_ebgp.add_edges_from((e for e in g_in.edges()
-            if e.src in ebgp_switches or e.dst in ebgp_switches),
-    bidirectional=True, type='ebgp')
-    ank_utils.aggregate_nodes(g_ebgp, ebgp_switches)
-    # need to recalculate as may have aggregated
-    ebgp_switches = list(g_ebgp.switches())
-    g_ebgp.log.debug("aggregated eBGP switches are %s" % ebgp_switches)
-    exploded_edges = ank_utils.explode_nodes(g_ebgp, ebgp_switches)
-    same_asn_edges = []
-    for edge in exploded_edges:
-        if edge.src.asn == edge.dst.asn:
-            same_asn_edges.append(edge)
-        else:
-            edge.multipoint = True
-    """TODO: remove up to here once compiler updated"""
-
-    g_ebgp.remove_edges_from(same_asn_edges)
-
-
-@call_log
+#@call_log
 def build_ibgp(anm):
     g_in = anm['input']
     g_phy = anm['phy']
@@ -109,10 +97,21 @@ def build_ibgp(anm):
 
     # Notify user of non-ibgp nodes
     non_ibgp_nodes = [n for n in g_bgp if n.ibgp_role is "Disabled"]
-    if len(non_ibgp_nodes) < 10:
+    if 0 < len(non_ibgp_nodes) < 10:
         log.info("Skipping iBGP for iBGP disabled nodes: %s" % non_ibgp_nodes)
     elif len(non_ibgp_nodes) >= 10:
-        log.info("Skipping iBGP for more than  10 iBGP disabled nodes: refer to visualization for resulting topology.")
+        log.info("Skipping iBGP for more than 10 iBGP disabled nodes: refer to visualization for resulting topology.")
+
+    # warn for any nodes that have RR set but no rr_cluster, or HRR set and no hrr_cluster
+    rr_mismatch = [n for n in ibgp_nodes if n.ibgp_role == "RR" and n.rr_cluster is None]
+    if len(rr_mismatch):
+        log.warning("Some routers are set as RR but have no rr_cluster: %s. Please specify an rr_cluster for peering."
+            % ", ".join(str(n) for n in rr_mismatch))
+
+    hrr_mismatch = [n for n in ibgp_nodes if n.ibgp_role == "HRR" and n.hrr_cluster is None]
+    if len(hrr_mismatch):
+        log.warning("Some routers are set as HRR but have no hrr_cluster: %s. Please specify an hrr_cluster for peering."
+            % ", ".join(str(n) for n in hrr_mismatch))
 
     for asn, asn_devices in ank_utils.groupby("asn", ibgp_nodes):
         asn_devices = list(asn_devices)
@@ -183,12 +182,12 @@ def build_ibgp(anm):
         g_bgp.add_edges_from(up_links, type='ibgp', direction='up')
         g_bgp.add_edges_from(down_links, type='ibgp', direction='down')
 
-@call_log
+#@call_log
 def build_bgp(anm):
     """Build iBGP end eBGP overlays"""
     # eBGP
     g_in = anm['input']
-    g_phy = anm['phy']
+    g_l3 = anm['layer3']
 
     if not anm['phy'].data.enable_routing:
         log.info("Routing disabled, not configuring BGP")
@@ -200,34 +199,18 @@ def build_bgp(anm):
 
     """TODO: remove from here once compiler updated"""
     g_bgp = anm.add_overlay("bgp", directed=True)
-    g_bgp.add_nodes_from(g_in.routers())
-    ebgp_edges = [edge for edge in g_in.edges() if not edge.attr_equal("asn")]
-    g_bgp.add_edges_from(ebgp_edges, bidirectional=True, type='ebgp')
+    g_bgp.add_nodes_from(g_l3.routers())
+    edges_to_add = [e for e in g_l3.edges()
+    if e.src in g_bgp and e.dst in g_bgp]
+    g_bgp.add_edges_from(edges_to_add, bidirectional = True)
+    ank_utils.copy_int_attr_from(g_l3, g_bgp, "multipoint")
 
-    ebgp_switches = [n for n in g_in.switches()
-            if not ank_utils.neigh_equal(g_phy, n, "asn")]
-    g_bgp.add_nodes_from(ebgp_switches, retain=['asn'])
-    log.debug("eBGP switches are %s" % ebgp_switches)
-    g_bgp.add_edges_from((e for e in g_in.edges()
-            if e.src in ebgp_switches or e.dst in ebgp_switches), bidirectional=True, type='ebgp')
-    ank_utils.aggregate_nodes(g_bgp, ebgp_switches)
-    ebgp_switches = list(g_bgp.switches()) # need to recalculate as may have aggregated
-    log.debug("aggregated eBGP switches are %s" % ebgp_switches)
-    exploded_edges = ank_utils.explode_nodes(g_bgp, ebgp_switches)
+    # remove ibgp links
 
-    same_asn_edges = []
-    for edge in exploded_edges:
-        if edge.src.asn == edge.dst.asn:
-            same_asn_edges.append(edge)
-        else:
-            edge.multipoint = True
     """TODO: remove up to here once compiler updated"""
+    ank_utils.copy_attr_from(g_in, g_bgp, "custom_config_bgp", dst_attr="custom_config")
 
-    g_bgp.remove_edges_from(same_asn_edges)
-
-
-    build_ibgp(anm)
-
+    log.info("Building eBGP")
     ebgp_nodes = [d for d in g_bgp if any(
         edge.type == 'ebgp' for edge in d.edges())]
     g_bgp.update(ebgp_nodes, ebgp=True)
@@ -238,12 +221,16 @@ def build_bgp(anm):
 
     for edge in g_bgp.edges(type='ibgp'):
         # TODO: need interface querying/selection. rather than hard-coded ids
+        #TODO: create a new port (once API allows) rarher than binding to loopback zero
         edge.bind_interface(edge.src, 0)
 
     #TODO: need to initialise interface zero to be a loopback rather than physical type
+    #TODO: wat is this for?
     for node in g_bgp:
         for interface in node.interfaces():
             interface.multipoint = any(e.multipoint for e in interface.edges())
 
+    log.info("Building iBGP")
+    build_ibgp(anm)
     build_ibgp_v4(anm)
     build_ibgp_v6(anm)
