@@ -3,7 +3,20 @@ import autonetkit.ank as ank_utils
 
 from autonetkit.ank_utils import call_log
 
-@call_log
+#TODO: extract the repeated code and use the layer2  and layer3 graphs
+def build_igp(anm):
+    build_ospf(anm)
+    build_eigrp(anm)
+    build_isis(anm)
+
+    g_igp = anm.add_overlay("igp")
+    igp_protocols = ["ospf", "eigrp", "isis"]
+    for protocol in igp_protocols:
+        g_protocol = anm[protocol]
+        g_igp.add_nodes_from(g_protocol, igp = protocol)
+        g_igp.add_edges_from(g_protocol.edges(), igp = protocol)
+
+#@call_log
 def build_ospf(anm):
     """
     Build OSPF graph.
@@ -20,9 +33,9 @@ def build_ospf(anm):
     """
     import netaddr
     g_in = anm['input']
+    g_l3 = anm['layer3']
     # add regardless, so allows quick check of node in anm['ospf'] in compilers
     g_ospf = anm.add_overlay("ospf")
-
     if not anm['phy'].data.enable_routing:
         g_ospf.log.info("Routing disabled, not configuring OSPF")
         return
@@ -31,18 +44,20 @@ def build_ospf(anm):
         g_ospf.log.debug("No OSPF nodes")
         return
 
-    g_ospf.add_nodes_from(g_in.l3devices(igp = "ospf"), retain=['asn'])
-    g_ospf.add_nodes_from(g_in.switches(), retain=['asn'])
-    g_ospf.add_edges_from(g_in.edges())
+    ospf_nodes = [n for n in g_l3 if n['phy'].igp == "ospf"]
+    g_ospf.add_nodes_from(ospf_nodes)
+    g_ospf.add_edges_from(g_l3.edges(), warn = False)
+    ank_utils.copy_int_attr_from(g_l3, g_ospf, "multipoint")
+
+    #TODO: work out why this doesnt work
+    #ank_utils.copy_int_attr_from(g_in, g_ospf, "ospf_cost", dst_attr="cost",  type=int, default = 1)
+    for node in g_ospf:
+        for interface in node.physical_interfaces():
+            interface.cost = 1
 
     ank_utils.copy_attr_from(g_in, g_ospf, "ospf_area", dst_attr="area")
-    ank_utils.copy_edge_attr_from(g_in, g_ospf, "ospf_cost",
-        dst_attr="cost",  type=int, default = 1)
-
-    ank_utils.aggregate_nodes(g_ospf, g_ospf.switches())
-    exploded_edges = ank_utils.explode_nodes(g_ospf, g_ospf.switches())
-    for edge in exploded_edges:
-        edge.multipoint = True
+    #ank_utils.copy_edge_attr_from(g_in, g_ospf, "ospf_cost", dst_attr="cost",  type=int, default = 1)
+    ank_utils.copy_attr_from(g_in, g_ospf, "custom_config_ospf", dst_attr="custom_config")
 
     g_ospf.remove_edges_from([link for link in g_ospf.edges(
     ) if link.src.asn != link.dst.asn])  # remove inter-AS links
@@ -137,7 +152,7 @@ def build_ospf(anm):
         router.loopback_zero.cost = 0
         router.process_id = router.asn
 
-@call_log
+#@call_log
 def ip_to_net_ent_title_ios(ip_addr):
     """ Converts an IP address into an OSI Network Entity Title
     suitable for use in IS-IS on IOS.
@@ -159,11 +174,12 @@ def ip_to_net_ent_title_ios(ip_addr):
     return ".".join([area_id, ip_octets[0:4], ip_octets[4:8], ip_octets[8:12],
                      "00"])
 
-@call_log
+#@call_log
 def build_eigrp(anm):
     """Build eigrp overlay"""
     g_in = anm['input']
     # add regardless, so allows quick check of node in anm['isis'] in compilers
+    g_l3 = anm['layer3']
     g_eigrp = anm.add_overlay("eigrp")
 
     if not anm['phy'].data.enable_routing:
@@ -173,10 +189,13 @@ def build_eigrp(anm):
     if not any(n.igp == "eigrp" for n in g_in):
         log.debug("No EIGRP nodes")
         return
-    g_ipv4 = anm['ipv4']
-    g_eigrp.add_nodes_from(g_in.l3devices(igp = "eigrp"), retain=['asn'])
-    g_eigrp.add_nodes_from(g_in.switches(), retain=['asn'])
-    g_eigrp.add_edges_from(g_in.edges())
+    eigrp_nodes = [n for n in g_l3 if n['phy'].igp == "eigrp"]
+    g_eigrp.add_nodes_from(eigrp_nodes)
+    g_eigrp.add_edges_from(g_l3.edges(), warn = False)
+    ank_utils.copy_int_attr_from(g_l3, g_eigrp, "multipoint")
+
+    ank_utils.copy_attr_from(g_in, g_eigrp, "custom_config_eigrp", dst_attr="custom_config")
+
 # Merge and explode switches
     ank_utils.aggregate_nodes(g_eigrp, g_eigrp.switches())
     exploded_edges = ank_utils.explode_nodes(g_eigrp,
@@ -188,7 +207,6 @@ def build_eigrp(anm):
         [link for link in g_eigrp.edges() if link.src.asn != link.dst.asn])
 
     for node in g_eigrp:
-        ip_node = g_ipv4.node(node)
         node.process_id = node.asn
 
     for link in g_eigrp.edges():
@@ -199,11 +217,12 @@ def build_eigrp(anm):
             interface.metric = edge.metric
             interface.multipoint = edge.multipoint
 
-@call_log
+#@call_log
 def build_isis(anm):
     """Build isis overlay"""
     g_in = anm['input']
     # add regardless, so allows quick check of node in anm['isis'] in compilers
+    g_l3 = anm['layer3']
     g_isis = anm.add_overlay("isis")
 
     if not anm['phy'].data.enable_routing:
@@ -213,15 +232,14 @@ def build_isis(anm):
     if not any(n.igp == "isis" for n in g_in):
         g_isis.log.debug("No ISIS nodes")
         return
+
+    isis_nodes = [n for n in g_l3 if n['phy'].igp == "isis"]
+    g_isis.add_nodes_from(isis_nodes)
+    g_isis.add_edges_from(g_l3.edges(), warn = False)
+    ank_utils.copy_int_attr_from(g_l3, g_isis, "multipoint")
+
     g_ipv4 = anm['ipv4']
-    g_isis.add_nodes_from(g_in.l3devices(igp = "isis"), retain=['asn'])
-    g_isis.add_nodes_from(g_in.switches(), retain=['asn'])
-    g_isis.add_edges_from(g_in.edges())
-# Merge and explode switches
-    ank_utils.aggregate_nodes(g_isis, g_isis.switches())
-    exploded_edges = ank_utils.explode_nodes(g_isis, g_isis.switches())
-    for edge in exploded_edges:
-        edge.multipoint = True
+    ank_utils.copy_attr_from(g_in, g_isis, "custom_config_isis", dst_attr="custom_config")
 
     g_isis.remove_edges_from(
         [link for link in g_isis.edges() if link.src.asn != link.dst.asn])
