@@ -7,8 +7,10 @@ from autonetkit.ank_utils import call_log
 
 SETTINGS = autonetkit.config.settings
 
+#TODO: refactor to go in chronological workflow order
 
-@call_log
+
+#@call_log
 def manual_ipv6_loopback_allocation(anm):
     """Applies manual IPv6 allocation"""
 
@@ -29,7 +31,7 @@ def manual_ipv6_loopback_allocation(anm):
 
     g_ipv6.data.loopback_blocks = loopback_blocks
 
-@call_log
+#@call_log
 def extract_ipv6_blocks(anm):
 
     # TODO: set all these blocks globally in config file, rather than repeated in load, build_network, compile, etc
@@ -77,7 +79,7 @@ def extract_ipv6_blocks(anm):
 
     return (infra_block, loopback_block, vrf_loopback_block)
 
-@call_log
+#@call_log
 def manual_ipv6_infrastructure_allocation(anm):
     """Applies manual IPv6 allocation"""
 
@@ -86,7 +88,7 @@ def manual_ipv6_infrastructure_allocation(anm):
     log.info('Using specified IPv6 infrastructure allocation')
 
     for node in g_ipv6.l3devices():
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if not interface['input'].is_bound:
                 continue  # unbound interface
             ip_address = netaddr.IPAddress(interface['input'
@@ -132,7 +134,7 @@ def manual_ipv6_infrastructure_allocation(anm):
     # also need to form aggregated IP blocks (used for e.g. routing prefix
     # advertisement)
     # import autonetkit
-    # autonetkit.update_http(anm)
+    # autonetkit.update_vis(anm)
 
     infra_blocks = {}
     for (asn, devices) in g_ipv6.groupby('asn').items():
@@ -143,7 +145,7 @@ def manual_ipv6_infrastructure_allocation(anm):
 
     g_ipv6.data.infra_blocks = infra_blocks
 
-@call_log
+#@call_log
 def build_ipv6(anm):
     """Builds IPv6 graph, using nodes and edges from IP graph"""
     import netaddr
@@ -151,6 +153,9 @@ def build_ipv6(anm):
 
     # uses the nodes and edges from ipv4
 
+
+    #TODO: do we also need to copy across the asn for broadcast domains?
+
     g_ipv6 = anm.add_overlay('ipv6')
     g_ip = anm['ip']
     g_in = anm['input']
@@ -161,11 +166,10 @@ def build_ipv6(anm):
     (infra_block, loopback_block, secondary_loopback_block) = \
         extract_ipv6_blocks(anm)
 
-    block_message = "IPv6 allocations: Infrastructure: %s, Loopback: %s" % (infra_block, loopback_block)
     if any(i for n in g_ip.nodes() for i in
-     n.loopback_interfaces if not i.is_loopback_zero):
-        block_message += " Secondary Loopbacks: %s" % secondary_loopback_block
-    log.info(block_message)
+     n.loopback_interfaces() if not i.is_loopback_zero):
+        block_message = "IPv6 Secondary Loopbacks: %s" % secondary_loopback_block
+        log.info(block_message)
 
     # TODO: replace this with direct allocation to interfaces in ip alloc plugin
     allocated = sorted([n for n in g_ip if n['input'].loopback_v6])
@@ -175,6 +179,7 @@ def build_ipv6(anm):
         log.info("Using user-specified IPv6 loopback addresses")
         manual_ipv6_loopback_allocation(anm)
     else:
+        log.info("Allocating from IPv6 loopback block: %s" % loopback_block)
         if len(allocated):
             log.warning("Using automatic IPv6 loopback allocation. IPv6 loopback addresses specified on nodes %s will be ignored." % allocated)
         else:
@@ -186,7 +191,7 @@ def build_ipv6(anm):
 
     manual_alloc_devices = set()
     for device in l3_devices:
-        physical_interfaces = list(device.physical_interfaces)
+        physical_interfaces = list(device.physical_interfaces())
         allocated = list(interface.ipv6_address for interface in physical_interfaces if interface.is_bound)
         if all(interface.ipv6_address for interface in
                physical_interfaces if interface.is_bound):
@@ -196,13 +201,14 @@ def build_ipv6(anm):
         log.info("Using user-specified IPv6 infrastructure addresses")
         manual_alloc_ipv6_infrastructure = True
     else:
+        log.info("Allocating from IPv6 Infrastructure block: %s" % infra_block)
         manual_alloc_ipv6_infrastructure = False
         # warn if any set
         allocated = []
         unallocated = []
         for node in l3_devices:
-            allocated += sorted([i for i in node.physical_interfaces if i.is_bound and i.ipv6_address])
-            unallocated += sorted([i for i in node.physical_interfaces if i.is_bound and not i.ipv6_address])
+            allocated += sorted([i for i in node.physical_interfaces() if i.is_bound and i.ipv6_address])
+            unallocated += sorted([i for i in node.physical_interfaces() if i.is_bound and not i.ipv6_address])
 
         #TODO: what if IP is set but not a prefix?
         if len(allocated):
@@ -225,16 +231,18 @@ def build_ipv6(anm):
                     interface.subnet = edge.dst.subnet  # from collision domain
 
     ipv6.allocate_vrf_loopbacks(g_ipv6, secondary_loopback_block)
+    for node in g_ipv6:
+        node.static_routes = []
 
     for node in g_ipv6.routers():
         #TODO: test this code
         node.loopback_zero.ip_address = node.loopback
         node.loopback_zero.subnet = netaddr.IPNetwork("%s/32" % node.loopback)
-        for interface in node.loopback_interfaces:
+        for interface in node.loopback_interfaces():
             if not interface.is_loopback_zero:
                 interface.ip_address = interface.loopback #TODO: fix this inconsistency elsewhere
 
-@call_log
+#@call_log
 def manual_ipv4_infrastructure_allocation(anm):
     """Applies manual IPv4 allocation"""
 
@@ -243,7 +251,7 @@ def manual_ipv4_infrastructure_allocation(anm):
     log.info('Using specified IPv4 infrastructure allocation')
 
     for node in g_ipv4.l3devices():
-        for interface in node.physical_interfaces:
+        for interface in node.physical_interfaces():
             if not interface['input'].is_bound:
                 continue  # unbound interface
             ip_address = netaddr.IPAddress(interface['input'
@@ -293,7 +301,7 @@ def manual_ipv4_infrastructure_allocation(anm):
     # also need to form aggregated IP blocks (used for e.g. routing prefix
     # advertisement)
     # import autonetkit
-    # autonetkit.update_http(anm)
+    # autonetkit.update_vis(anm)
 
     infra_blocks = {}
     for (asn, devices) in g_ipv4.groupby('asn').items():
@@ -305,7 +313,7 @@ def manual_ipv4_infrastructure_allocation(anm):
     g_ipv4.data.infra_blocks = infra_blocks
 
 
-@call_log
+#@call_log
 def manual_ipv4_loopback_allocation(anm):
     """Applies manual IPv4 allocation"""
 
@@ -327,78 +335,15 @@ def manual_ipv4_loopback_allocation(anm):
     g_ipv4.data.loopback_blocks = loopback_blocks
 
 
-@call_log
+#@call_log
 def build_ip(anm):
-    #TODO: use the l3_conn graph
     g_ip = anm.add_overlay('ip')
-    g_in = anm['input']
-    g_graphics = anm['graphics']
-    g_phy = anm['phy']
+    g_l2_bc = anm['layer2_bc']
+    # Retain arbitrary ASN allocation for IP addressing
+    g_ip.add_nodes_from(g_l2_bc, retain=["asn", "broadcast_domain"])
+    g_ip.add_edges_from(g_l2_bc.edges())
 
-    #TODO: add these from layer2 graph - and scrap g_ip: clone g_layer2 to g_ipv4 and g_ipv6
-    g_ip.add_nodes_from(g_phy)
-    g_ip.add_edges_from(g_phy.edges())
-
-    ank_utils.aggregate_nodes(g_ip, g_ip.switches())
-
-    edges_to_split = [edge for edge in g_ip.edges()
-        if edge.src.is_l3device() and edge.dst.is_l3device()]
-    for edge in edges_to_split:
-        edge.split = True  # mark as split for use in building nidb
-
-    split_created_nodes = list(ank_utils.split(g_ip, edges_to_split,
-                               retain=['split'],
-                               id_prepend='cd'))
-    for node in split_created_nodes:
-        node['graphics'].x = ank_utils.neigh_average(g_ip, node, 'x',
-                g_graphics) + 0.1
-
-         # temporary fix for gh-90
-
-        node['graphics'].y = ank_utils.neigh_average(g_ip, node, 'y',
-                g_graphics) + 0.1
-
-            # temporary fix for gh-90
-
-        asn = ank_utils.neigh_most_frequent(g_ip, node, 'asn', g_phy)  # arbitrary choice
-        node['graphics'].asn = asn
-        node.asn = asn  # need to use asn in IP overlay for aggregating subnets
-
-    switch_nodes = g_ip.switches()  # regenerate due to aggregated
-    g_ip.update(switch_nodes, broadcast_domain=True)
-
-                 # switches are part of collision domain
-
-    g_ip.update(split_created_nodes, broadcast_domain=True)
-
-# Assign collision domain to a host if all neighbours from same host
-
-    for node in split_created_nodes:
-        if ank_utils.neigh_equal(g_ip, node, 'host', g_phy):
-            node.host = ank_utils.neigh_attr(g_ip, node, 'host',
-                    g_phy).next()  # first attribute
-
-    # set collision domain IPs
-    #TODO; work out why this throws a json exception
-    #autonetkit.ank.set_node_default(g_ip,  broadcast_domain=False)
-
-    for node in g_ip.nodes('broadcast_domain'):
-        graphics_node = g_graphics.node(node)
-        #graphics_node.device_type = 'broadcast_domain'
-        if node.is_switch():
-            node['phy'].broadcast_domain = True
-        if not node.is_switch():
-            # use node sorting, as accomodates for numeric/string names
-            graphics_node.device_type = 'broadcast_domain'
-            neighbors = sorted(neigh for neigh in node.neighbors())
-            label = '_'.join(neigh.label for neigh in neighbors)
-            cd_label = 'cd_%s' % label  # switches keep their names
-            node.label = cd_label
-            node.cd_id = cd_label
-            graphics_node.label = cd_label
-            node.device_type = "broadcast_domain"
-
-@call_log
+#@call_log
 def extract_ipv4_blocks(anm):
 
     # TODO: set all these blocks globally in config file, rather than repeated in load, build_network, compile, etc
@@ -449,7 +394,7 @@ def extract_ipv4_blocks(anm):
     return (infra_block, loopback_block, vrf_loopback_block)
 
 
-@call_log
+#@call_log
 def build_ipv4(anm, infrastructure=True):
     """Builds IPv4 graph"""
 
@@ -462,8 +407,12 @@ def build_ipv4(anm, infrastructure=True):
 
     # Copy ASN attribute chosen for collision domains (used in alloc algorithm)
 
-    ank_utils.copy_attr_from(g_ip, g_ipv4, 'asn',
-                             nbunch=g_ipv4.nodes('broadcast_domain'))
+    ank_utils.copy_attr_from(g_ip, g_ipv4, 'asn', nbunch=g_ipv4.nodes('broadcast_domain'))
+    # work around until fall-through implemented
+    vswitches = [n for n in g_ip.nodes()
+    if n['layer2'].device_type == "switch"
+    and n['layer2'].device_subtype == "virtual"]
+    ank_utils.copy_attr_from(g_ip, g_ipv4, 'asn', nbunch=vswitches)
     g_ipv4.add_edges_from(g_ip.edges())
 
     # check if ip ranges have been specified on g_in
@@ -472,12 +421,10 @@ def build_ipv4(anm, infrastructure=True):
         extract_ipv4_blocks(anm)
 
 #TODO: don't present if using manual allocation
-    block_message = "IPv4 allocations: Infrastructure: %s, Loopback: %s" % (infra_block, loopback_block)
     if any(i for n in g_ip.nodes() for i in
-     n.loopback_interfaces if not i.is_loopback_zero):
-        block_message += " Secondary Loopbacks: %s" % vrf_loopback_block
-
-    log.info(block_message)
+     n.loopback_interfaces() if not i.is_loopback_zero):
+        block_message = "IPv4 Secondary Loopbacks: %s" % vrf_loopback_block
+        log.info(block_message)
 
     # See if IP addresses specified on each interface
 
@@ -486,7 +433,7 @@ def build_ipv4(anm, infrastructure=True):
 
     manual_alloc_devices = set()
     for device in l3_devices:
-        physical_interfaces = list(device.physical_interfaces)
+        physical_interfaces = list(device.physical_interfaces())
         allocated = list(interface.ipv4_address for interface in physical_interfaces if interface.is_bound)
         if all(interface.ipv4_address for interface in
                physical_interfaces if interface.is_bound):
@@ -495,13 +442,14 @@ def build_ipv4(anm, infrastructure=True):
     if manual_alloc_devices == set(l3_devices):
         manual_alloc_ipv4_infrastructure = True
     else:
+        log.info("Allocating from IPv4 infrastructure block: %s" % infra_block)
         manual_alloc_ipv4_infrastructure = False
         # warn if any set
         allocated = []
         unallocated = []
         for node in l3_devices:
-            allocated += sorted([i for i in node.physical_interfaces if i.is_bound and i.ipv4_address])
-            unallocated += sorted([i for i in node.physical_interfaces if i.is_bound and not i.ipv4_address])
+            allocated += sorted([i for i in node.physical_interfaces() if i.is_bound and i.ipv4_address])
+            unallocated += sorted([i for i in node.physical_interfaces() if i.is_bound and not i.ipv4_address])
 
         #TODO: what if IP is set but not a prefix?
         if len(allocated):
@@ -518,6 +466,7 @@ def build_ipv4(anm, infrastructure=True):
     if g_in.data.alloc_ipv4_loopbacks is False:
         manual_ipv4_loopback_allocation(anm)
     else:
+        log.info("Allocating from IPv4 loopback block: %s" % loopback_block)
         # Check if some nodes are allocated
         allocated = sorted([n for n in g_ip if n['input'].loopback_v4])
         unallocated = sorted([n for n in g_ip if not n['input'].loopback_v4])
@@ -533,10 +482,12 @@ def build_ipv4(anm, infrastructure=True):
 
     # TODO: replace this with direct allocation to interfaces in ip alloc plugin
     #TODO: add option for nonzero interfaces on node - ie node.secondary_loopbacks
+    for node in g_ipv4:
+        node.static_routes = []
 
     for node in g_ipv4.routers():
         node.loopback_zero.ip_address = node.loopback
         node.loopback_zero.subnet = netaddr.IPNetwork("%s/32" % node.loopback)
-        for interface in node.loopback_interfaces:
+        for interface in node.loopback_interfaces():
             if not interface.is_loopback_zero:
                 interface.ip_address = interface.loopback #TODO: fix this inconsistency elsewhere
