@@ -6,11 +6,11 @@ import autonetkit.ank as ank_utils
 import itertools
 from autonetkit.ank_utils import call_log
 
-@call_log
+#@call_log
 def mpls_te(anm):
     g_in = anm['input']
     g_phy = anm['phy']
-    g_l3_conn = anm['l3_conn']
+    g_l3 = anm['layer3']
 
     # add regardless, so allows quick check of node in anm['mpls_te'] in compilers
 
@@ -25,16 +25,16 @@ def mpls_te(anm):
 
     # build up edge list sequentially, to provide meaningful messages for multipoint links
 
-    multipoint_edges = [e for e in g_l3_conn.edges() if e.multipoint]
+    multipoint_edges = [e for e in g_l3.edges() if e.multipoint]
     if len(multipoint_edges):
         log.info('Excluding multi-point edges from MPLS TE topology: %s'
            % ', '.join(str(e) for e in multipoint_edges))
 
-    edges_to_add = set(g_l3_conn.edges()) - set(multipoint_edges)
+    edges_to_add = set(g_l3.edges()) - set(multipoint_edges)
     g_mpls_te.add_edges_from(edges_to_add)
 
 
-@call_log
+#@call_log
 def mpls_oam(anm):
     g_in = anm['input']
 
@@ -49,7 +49,7 @@ def mpls_oam(anm):
     if use_mpls_oam:
         g_mpls_oam.add_nodes_from(g_in.routers())
 
-@call_log
+#@call_log
 def vrf_pre_process(anm):
     """Marks nodes in g_in as appropriate based on vrf roles.
     CE nodes -> ibgp_role = Disabled, so not in iBGP (this is allocated later)
@@ -60,7 +60,7 @@ def vrf_pre_process(anm):
         log.debug("Marking CE node %s as non-ibgp" % node)
         node['input'].ibgp_role = "Disabled"
 
-@call_log
+#@call_log
 def allocate_vrf_roles(g_vrf):
     """Allocate VRF roles"""
     g_phy = g_vrf.anm['phy']
@@ -102,10 +102,10 @@ def allocate_vrf_roles(g_vrf):
         message = ", ".join(str(n) for n in sorted(p_set_nodes))
         g_vrf.log.info("VRF role set to P for %s" % message)
 
-@call_log
+#@call_log
 def add_vrf_loopbacks(g_vrf):
     """Adds loopbacks for VRFs, and stores VRFs connected to PE router"""
-    #autonetkit.update_http(anm)
+    #autonetkit.update_vis(anm)
     for node in g_vrf.nodes(vrf_role="PE"):
         node_vrf_names = {n.vrf for n in node.neighbors(vrf_role="CE")}
         node.node_vrf_names = node_vrf_names
@@ -115,7 +115,7 @@ def add_vrf_loopbacks(g_vrf):
             node.add_loopback(vrf_name=vrf_name,
                               description="loopback for vrf %s" % vrf_name)
 
-@call_log
+#@call_log
 def build_ibgp_vpn_v4(anm):
     """Based on the ibgp_v4 hierarchy rules.
     Exceptions:
@@ -200,12 +200,12 @@ def build_ibgp_vpn_v4(anm):
 
     # also need to modify the ibgp_v4 and ibgp_v6 graphs
 
-@call_log
+#@call_log
 def build_mpls_ldp(anm):
     """Builds MPLS LDP"""
     g_in = anm['input']
     g_vrf = anm['vrf']
-    g_l3conn = anm['l3_conn']
+    g_layer3 = anm['layer3']
     g_mpls_ldp = anm.add_overlay("mpls_ldp")
     nodes_to_add = [n for n in g_in.routers()
             if n['vrf'].vrf_role in ("PE", "P")]
@@ -215,20 +215,20 @@ def build_mpls_ldp(anm):
     pe_nodes = set(g_vrf.nodes(vrf_role = "PE"))
     p_nodes = set(g_vrf.nodes(vrf_role = "P"))
 
-    pe_to_pe_edges = (e for e in g_l3conn.edges()
+    pe_to_pe_edges = (e for e in g_layer3.edges()
             if e.src in pe_nodes and e.dst in pe_nodes)
     g_mpls_ldp.add_edges_from(pe_to_pe_edges)
 
-    pe_to_p_edges = (e for e in g_l3conn.edges()
+    pe_to_p_edges = (e for e in g_layer3.edges()
             if e.src in pe_nodes and e.dst in p_nodes
             or e.src in p_nodes and e.dst in pe_nodes)
     g_mpls_ldp.add_edges_from(pe_to_p_edges)
 
-    p_to_p_edges = (e for e in g_l3conn.edges()
+    p_to_p_edges = (e for e in g_layer3.edges()
             if e.src in p_nodes and e.dst in p_nodes)
     g_mpls_ldp.add_edges_from(p_to_p_edges)
 
-@call_log
+#@call_log
 def mark_ebgp_vrf(anm):
     g_ebgp = anm['ebgp']
     g_vrf = anm['vrf']
@@ -248,11 +248,11 @@ def mark_ebgp_vrf(anm):
             edge.exclude = True
             edge.vrf = edge.dst['vrf'].vrf
 
-@call_log
+#@call_log
 def build_vrf(anm):
     """Build VRF Overlay"""
     g_in = anm['input']
-    g_l3conn = anm['l3_conn']
+    g_layer3 = anm['layer3']
     g_vrf = anm.add_overlay("vrf")
 
     import autonetkit
@@ -268,20 +268,25 @@ def build_vrf(anm):
     vrf_pre_process(anm)
 
     def is_pe_ce_edge(edge):
+        if not(edge.src in g_vrf and edge.dst in g_vrf):
+            return False
+
         src_vrf_role = g_vrf.node(edge.src).vrf_role
         dst_vrf_role = g_vrf.node(edge.dst).vrf_role
         return (src_vrf_role, dst_vrf_role) in (("PE", "CE"), ("CE", "PE"))
 
-    vrf_add_edges = (e for e in g_l3conn.edges()
+    vrf_add_edges = (e for e in g_layer3.edges()
            if is_pe_ce_edge(e))
     #TODO: should mark as being towards PE or CE
     g_vrf.add_edges_from(vrf_add_edges)
 
     def is_pe_p_edge(edge):
+        if not(edge.src in g_vrf and edge.dst in g_vrf):
+            return False
         src_vrf_role = g_vrf.node(edge.src).vrf_role
         dst_vrf_role = g_vrf.node(edge.dst).vrf_role
         return (src_vrf_role, dst_vrf_role) in (("PE", "P"), ("P", "PE"))
-    vrf_add_edges = (e for e in g_l3conn.edges()
+    vrf_add_edges = (e for e in g_layer3.edges()
             if is_pe_p_edge(e))
     g_vrf.add_edges_from(vrf_add_edges)
 
