@@ -2,6 +2,10 @@ import logging
 import logging.handlers
 import autonetkit.config as config
 
+class CustomAdapter(logging.LoggerAdapter):
+    def process(self, msg, kwargs):
+        return '[%s]: %s' % (self.extra['item'], msg), kwargs
+
 
 ank_logger = logging.getLogger("ANK")
 if not ank_logger.handlers:
@@ -9,6 +13,7 @@ if not ank_logger.handlers:
     ch = logging.StreamHandler()
     #ch.setLevel(logging.INFO)
     ch.setFormatter(console_formatter)
+    ch.setLevel(logging.INFO)
     ank_logger.addHandler(ch)
 
     file_logging = config.settings['Logging']['file']
