@@ -1,8 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-import functools
 import itertools
-import json
 import math
 import time
 from collections import defaultdict
@@ -69,7 +67,7 @@ class TreeNode(object):
         return self.loopback_group
 
     def is_interface(self):
-        return isinstance(self.host, autonetkit.anm.overlay_interface)
+        return isinstance(self.host, autonetkit.anm.NmPort)
 
     def is_host(self):
         return bool(self.host)
@@ -193,7 +191,7 @@ class IpTree(object):
 
         unallocated_nodes = self.unallocated_nodes
         key_func = lambda x: x.get(group_attr)
-        if all(isinstance(item, autonetkit.anm.overlay_interface)
+        if all(isinstance(item, autonetkit.anm.NmPort)
                and item.is_loopback for item in unallocated_nodes):
             key_func = lambda x: x.node.get(group_attr)  # interface, map key function to be the interface's node
 
@@ -208,7 +206,7 @@ class IpTree(object):
             items = sorted(list(items))
             subgraph = nx.DiGraph()
 
-            if all(isinstance(item, autonetkit.anm.overlay_interface)
+            if all(isinstance(item, autonetkit.anm.NmPort)
                    for item in items):
 
                 # interface
@@ -218,7 +216,7 @@ class IpTree(object):
                     prefixlen = 32 - subnet_size(len(items))  # group all loopbacks into single subnet
                     subgraph.add_node(parent_id, prefixlen=prefixlen,
                             loopback_group=True)
-                    for item in items:
+                    for item in sorted(items):
 
                     # subgraph.add_edge(node, child_a)
 
@@ -241,7 +239,7 @@ class IpTree(object):
                 prefixlen = 32 - subnet_size(len(items))  # group all loopbacks into single subnet
                 subgraph.add_node(parent_id, prefixlen=prefixlen,
                                   loopback_group=True)
-                for item in items:
+                for item in sorted(items):
 
                 # subgraph.add_edge(node, child_a)
 
@@ -255,7 +253,7 @@ class IpTree(object):
                 subgraph.node[root_node]['group_attr'] = attr_value
                 continue  # finished for loopbacks, continue only for collision domains
 
-            for item in items:
+            for item in sorted(items):
                 if item.broadcast_domain:
                     subgraph.add_node(self.next_node_id, prefixlen=32
                             - subnet_size(item.degree()), host=item)
@@ -303,7 +301,7 @@ class IpTree(object):
             # rebuild with parent nodes
 
             nodes_by_level = defaultdict(list)
-            for node in subgraph.nodes():
+            for node in sorted(subgraph.nodes()):
                 prefixlen = subgraph.node[node]['prefixlen']
                 nodes_by_level[prefixlen].append(node)
 
@@ -378,7 +376,7 @@ class IpTree(object):
 # add children of collision domains
 
         cd_nodes = [n for n in self if n.is_broadcast_domain()]
-        for cd in cd_nodes:
+        for cd in sorted(cd_nodes):
             for edge in sorted(cd.host.edges()):
 
                 # TODO: sort these
@@ -411,7 +409,7 @@ class IpTree(object):
 
                 iterhosts = node.subnet.iter_hosts()  # ensures start at .1 rather than .0
                 sub_children = node.children()
-                for sub_child in sub_children:
+                for sub_child in sorted(sub_children):
 
                     # TODO: tidy up this allocation to always record the subnet
 
@@ -440,7 +438,7 @@ class IpTree(object):
 
                 return
 
-            for child in children:
+            for child in sorted(children):
 
                 # traverse the tree
 
@@ -449,7 +447,7 @@ class IpTree(object):
                     child.subnet = subnet
                     iterhosts = child.subnet.iter_hosts()  # ensures start at .1 rather than .0
                     sub_children = child.children()
-                    for sub_child in sub_children:
+                    for sub_child in sorted(sub_children):
                         if sub_child.is_interface():
                             interface = sub_child.host
                             if interface.is_physical:
@@ -475,7 +473,7 @@ class IpTree(object):
                     child.subnet = subnet.next()
                     iterhosts = child.subnet.iter_hosts()  # ensures start at .1 rather than .0
                     sub_children = child.children()
-                    for sub_child in sub_children:
+                    for sub_child in sorted(sub_children):
                         if sub_child.is_interface() \
                             and not sub_child.host.is_loopback_zero:
 
@@ -550,7 +548,7 @@ class IpTree(object):
         # don't look at host nodes now - use loopback_groups
         #TODO: make check for interface and loopback zero now
         host_tree_nodes = [n for n in self if n.is_host()
-                            and isinstance(n.host, autonetkit.anm.OverlayNode)
+                            and isinstance(n.host, autonetkit.anm.NmNode)
                            and n.host.is_l3device()]
 
         # for host_tree_node in host_tree_nodes:
@@ -603,7 +601,7 @@ def allocate_infra(g_ip, address_block=None):
     log.info('Allocating v4 Infrastructure IPs')
     ip_tree = IpTree(address_block)
     assign_asn_to_interasn_cds(g_ip)
-    ip_tree.add_nodes(g_ip.nodes('broadcast_domain'))
+    ip_tree.add_nodes(sorted(g_ip.nodes('broadcast_domain')))
     ip_tree.build()
 
     # cd_tree = ip_tree.json()
@@ -625,7 +623,7 @@ def allocate_loopbacks(g_ip, address_block=None):
         address_block = netaddr.IPNetwork('192.168.0.0/22')
     log.info('Allocating v4 Primary Host loopback IPs')
     ip_tree = IpTree(address_block)
-    ip_tree.add_nodes(g_ip.l3devices())
+    ip_tree.add_nodes(sorted(g_ip.l3devices()))
     ip_tree.build()
 
     # loopback_tree = ip_tree.json()
@@ -639,7 +637,7 @@ def allocate_vrf_loopbacks(g_ip, address_block=None):
         address_block = netaddr.IPNetwork('172.16.0.0/24')
 
     secondary_loopbacks = [i for n in g_ip.nodes() for i in
-                           n.loopback_interfaces
+                           n.loopback_interfaces()
                            if not i.is_loopback_zero]
 
     if not len(secondary_loopbacks):
@@ -650,7 +648,7 @@ def allocate_vrf_loopbacks(g_ip, address_block=None):
     vrf_loopbacks = [i for i in secondary_loopbacks if i['vrf'
                      ].vrf_name]
 
-    ip_tree.add_nodes(vrf_loopbacks)
+    ip_tree.add_nodes(sorted(vrf_loopbacks))
 
     ip_tree.build()
 
